@@ -3,5 +3,6 @@ from .models import *
 from .topics import *
 from .point_redemption_model import PubSubPointRedemption
 from .whisper_model import PubSubWhisper
-from .subscribe_model import PubSubSubscription
+from .subscription_model import PubSubSubscription
 from .pubsub_moderation_action import PubSubModerationAction
+from .subscription_model import PubSubSubscription
